@@ -111,10 +111,8 @@ class GraphqlWsConsumer(ch_websocket.AsyncJsonWebsocketConsumer):
     subscription_confirmation_message = {"data": None, "errors": None}
 
     # The maximum number of threads designated for GraphQL requests
-    # processing. `None` means that default value is used. According to
-    # the Python documentation it is "the number of processors on the
-    # machine, multiplied by 5". See the `ThreadPoolExecutor` docs for
-    # details:
+    # processing. `None` means that default value is used. Default
+    # value depends on the Python version, check its documentation:
     # https://docs.python.org/3/library/concurrent.futures.html#concurrent.futures.ThreadPoolExecutor
     max_worker_threads = None
 
@@ -930,11 +928,19 @@ class GraphqlWsConsumer(ch_websocket.AsyncJsonWebsocketConsumer):
             """Wrap the `func` to init eventloop and to cleanup."""
             # Create an eventloop if this worker thread does not have
             # one yet. Eventually each worker will have its own
-            # eventloop for `func` can use it.
+            # eventloop so `func` can use it.
             try:
                 loop = asyncio.get_event_loop()
             except RuntimeError:
                 loop = asyncio.new_event_loop()
+                # Force the event loop of the worker thread have a
+                # single-threaded default executor, otherwise the total
+                # number of threads may (and will) grow up to the value
+                # of `default_max_workers * default_max_workers` for
+                # each `GraphqlWsConsumer` subclass!
+                loop.set_default_executor(
+                    concurrent.futures.ThreadPoolExecutor(max_workers=1)
+                )
                 asyncio.set_event_loop(loop)
 
             # Run a given function in a thread.
